{
  config,
  lib,
  pkgs,
  ...
}: {
  programs.helix = {
    enable = true;
    defaultEditor = true;

    settings = {
      # theme = "catppuccin_macchiato"; # Don't need this because the module themes it for us
      keys.normal.backspace = {
        b = ":run-shell-command zellij run -f -- just build";
        r = ":run-shell-command zellij run -f -- just run";
        t = ":run-shell-command zellij run -f -- just test";
        g = ":run-shell-command zellij run -fc -- lazygit";
        f = ":run-shell-command zellij run -fc -- broot";
      };
      editor = {
        line-number = "relative";
        lsp.display-messages = true;
        lsp.display-inlay-hints = true;
        cursor-shape = {
          insert = "bar";
          normal = "block";
          select = "underline";
        };
        cursorline = true;
        bufferline = "always";
        color-modes = true;
        soft-wrap = {
          enable = true;
          max-wrap = 25;
          wrap-indicator = "";
        };
      };
    };
    languages = {
      language = [
        {
          name = "python";
          language-id = "python";
          auto-format = true;
          file-types = ["py"];
          language-servers = ["ruff" "scls" "pylsp"];
        }
        {
          name = "typst";
          language-id = "typst";
          auto-format = false;
          file-types = ["typ"];
          language-servers = ["typst-lsp" "scls"];
        }
        {
          name = "rust";
          language-id = "rust";
          auto-format = true;
          file-types = ["rs"];
          roots = ["Cargo.lock"];
          language-servers = ["rust-analyzer" "scls"];
        }
        {
          name = "stub";
          scope = "text.stub";
          file-types = [];
          shebangs = [];
          roots = [];
          auto-format = false;
          language-servers = ["scls"];
        }
        {
          name = "nix";
          language-id = "nix";
          auto-format = true;
          file-types = ["nix"];
          roots = ["flake.lock" "flake.nix"];
          language-servers = ["nil" "scls"];
          formatter = {
            command = "alejandra";
            args = ["-q"];
          };
        }
        {
          name = "html";
          language-id = "html";
          auto-format = true;
          file-types = ["htm" "html"];
          language-servers = ["vscode-html-language-server" "vscode-eslint-language-server"];
        }
        {
          name = "css";
          language-id = "css";
          auto-format = true;
          file-types = ["css"];
          language-servers = ["vscode-css-language-server" "vscode-eslint-language-server"];
        }
        {
          name = "json";
          language-id = "json";
          auto-format = true;
          file-types = ["json"];
          language-servers = ["vscode-json-language-server" "vscode-eslint-language-server"];
        }
      ];
      language-server = {
        vscode-html-language-server = {
          command = "vscode-html-language-server";
        };
        vscode-css-language-server = {
          command = "vscode-css-language-server";
        };
        vscode-eslint-language-server = {
          command = "vscode-eslint-language-server";
        };
        vscode-json-language-server = {
          command = "vscode-json-language-server";
        };
        pylsp = {
          config.pylsp.plugins = {
            flake8 = {enabled = false;};
            autopep8 = {enabled = false;};
            mccabe = {enabled = false;};
            pycodestyle = {enabled = false;};
            pyflakes = {enabled = false;};
            pylint = {enabled = false;};
            yapf = {enabled = false;};
            ruff = {
              enabled = true;
              select = ["E" "F" "UP" "B" "SIM" "I" "PD" "NPY" "PERF" "FURB" "DOC" "TRY" "W" "R" "PL" "TCH" "Q" "PT" "ICN" "C4" "COM" "FBT" "S" "N"];
              ignore = ["F401"];
              lineLength = 120;
            };
          };
        };
        ruff = {
          command = "ruff-lsp";
        };
        typst-lsp = {
          command = "typst-lsp";
        };
        rust-analyzer = {
          command = "rust-analyzer";
        };
        nil = {
          command = "nil";
        };
        scls = {
          command = "simple-completion-language-server";
          config = {
            max_completion_items = 20;
            snippets_first = true;
            feature_words = true;
            feature_snippets = true;
            feature_unicode_input = true;
            feature_paths = true;
          };
        };
      };
    };
  };
  home.file = {
    "helix" = {
      source = ./snippets.toml;
      target = ".config/helix/external-snippets.toml";
    };
  };
}
